<?php
/**
 * dsconnector.php - SoftOne connector for Virtuemart
 * @version $Id: dsconnector.php 100 2014-09-20 13:16:55Z sv1jsb $
 * @author Dream Solutions
 * @author Andreas Porevopoulos sv1jsb
 * @copyright (C) 2010- Dream Solutions
 * @license http://www.gnu.org/licenses/gpl-3.0.html GNU/GPLv3, see license.txt
 * @package VirtueMart
 * @subpackage vmcustom
**/

defined ('_JEXEC') or die('Restricted access');

if (!class_exists('vmCustomPlugin')) require(JPATH_VM_PLUGINS . DS . 'vmcustomplugin.php');

require_once 'dslib.php';

class plgVmCustomDSConnector extends vmCustomPlugin {

	function __construct(& $subject, $config) {
        parent::__construct($subject, $config);
        $this->url=$this->params->get('custom_url');
        $this->apikey=$this->params->get('api_key');

	}
    
    function plgVmConfirmedOrder($cart, $order, $payment_method = '') {
        if(!empty($this->url) and !empty($this->apikey)){
            if(endswith($this->url, '/')) {
                $dsurl = $this->url . DS_CONNECTOR_SAVE_ORDER;
            } else {
                $dsurl = $this->url . '/' . DS_CONNECTOR_SAVE_ORDER;
            }
            $order_number = $order['details']['BT']->order_number;
            $a = array($order);
            $json_data = array("api_key" => $this->apikey, "data" => $a);
            $body = json_encode($json_data);
            $params = array('url' => $dsurl,
                'method' => 'POST',
                'post_fields' => $body, 
                'timeout' => 20
            );
            $curl = new CurlRequest();
            $curl->init($params);
            $result = $curl->exec();
            $code = intval($result['http_code']);
            switch ($code) {
                case 403:
                    $error = json_decode($result['body']);
                    logInfo(JText::_('PLG_VMCUSTOM_DSCONNECTOR_NO_TRANSFER') . $order_number, 'error');
                    logInfo($error->error, 'error');
                    $this->emailOnFail($order['details']['BT']->virtuemart_vendor_id, $order_number, $code, $error->error);
                    break;
                case 200:
                    logInfo(JText::_('PLG_VMCUSTOM_DSCONNECTOR_SUCCESS_TRANSFER') . $order_number);
                    break;
                default:
                    $error = $result['http_code_desc'];
                    logInfo(JText::_('PLG_VMCUSTOM_DSCONNECTOR_NO_TRANSFER') . $order_number, 'error');
                    logInfo(JText::sprintf('PLG_VMCUSTOM_DSCONNECTOR_MISC_TRANSFER', $code, $error), 'error');
                    $this->emailOnFail($order['details']['BT']->virtuemart_vendor_id, $order_number, $code, $error);
            }
        }
        return true;
    }

    function emailOnFail($vid, $order_number, $code, $error) {

        $vendorModel = VmModel::getModel('vendor');
        $vendorEmail = $vendorModel->getVendorEmail($vid);
        $vendorName = $vendorModel->getVendorName($vid);
        $mailer = JFactory::getMailer();
        $sender = array($vendorEmail, $vendorName);
        $mailer->setSender($sender);
        $mailer->addRecipient($vendorEmail);
        $mailer->setSubject('Error transporting order: ' . $order_number);
        $body = "There was an error transporting order no: ' . $order_number . '\n";
        $body = $body . "Code: ";
        $body = $body . $code. "\n";
        $body = $body . "Message: ";
        $body = $body . $error. "\n\n";
        $body = $body . "==================================\n";
        $body = $body . "Dream Solutions VM -> S1 connector\n";
        $mailer->setBody($body);
        $send = $mailer->Send();
        if ( $send !== true ) {
            logInfo('Error sending email: ' . $send->__toString());
        } else {
            logInfo('Mail sent');
        }
        return true;
    }

    
}